@@ -57,7 +57,7 @@ class API(ABCAPI):
         self.request_rescheduler = request_rescheduler or BlockingRequestRescheduler()
         self.response_validators: List["ABCResponseValidator"] = DEFAULT_RESPONSE_VALIDATORS
         self.request_validators: List["ABCRequestValidator"] = DEFAULT_REQUEST_VALIDATORS  # type: ignore
-        self.captcha_handler: Optional[CaptchaHandler] = None
+        self.captcha_handler: Optional["CaptchaHandler"] = None
 
     async def request(self, method: str, data: dict) -> dict:
         """Makes a single request opening a session"""
@@ -70,8 +70,8 @@ class API(ABCAPI):
                 data=data,  # type: ignore
                 params={"access_token": token, "v": self.API_VERSION},
             )
-        logger.debug("Request {} with {} data returned {}".format(method, data, response))
-        return await self.validate_response(method, data, response)
+        logger.debug("Request {} with {} data returned {}", method, data, response)
+        return await self.validate_response(method, data, response)  # type: ignore
 
     async def request_many(
         self, requests: Iterable[APIRequest]  # type: ignore
@@ -86,8 +86,8 @@ class API(ABCAPI):
                     data=data,  # noqa
                     params={"access_token": token, "v": self.API_VERSION},  # noqa
                 )
-            logger.debug("Request {} with {} data returned {}".format(method, data, response))
-            yield await self.validate_response(method, data, response)
+            logger.debug("Request {} with {} data returned {}", method, data, response)
+            yield await self.validate_response(method, data, response)  # type: ignore
 
     async def validate_response(
         self, method: str, data: dict, response: Union[dict, str]
@@ -95,7 +95,7 @@ class API(ABCAPI):
         """Validates response from VK,
         to change validations change API.response_validators (list of ResponseValidator's)"""
         for validator in self.response_validators:
-            response = await validator.validate(method, data, response, self)
+            response = await validator.validate(method, data, response, self)  # type: ignore
         logger.debug("API response was validated")
         return response  # type: ignore
 
@@ -103,7 +103,7 @@ class API(ABCAPI):
         """Validates requests from VK,
         to change validations change API.request_validators (list of RequestValidator's)"""
         for validator in self.request_validators:
-            request = await validator.validate(request)
+            request = await validator.validate(request)  # type: ignore
         logger.debug("API request was validated")
         return request  # type: ignore
 
