@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Callable, Generic, List, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, Generic, List, TypeVar
 
 from vkbottle.modules import logger
 
@@ -9,7 +9,7 @@ if TYPE_CHECKING:
     from vkbottle.api.abc import ABCAPI
     from vkbottle.dispatch.dispenser.abc import ABCStateDispenser
     from vkbottle.dispatch.handlers import ABCHandler
-    from vkbottle.tools.dev.mini_types.user import MessageMin
+    from vkbottle.tools.dev.mini_types.base import BaseMessageMin
 
 DEFAULT_STATE_KEY = "peer_id"
 
@@ -21,7 +21,8 @@ F_contra = TypeVar("F_contra", contravariant=True)
 class ABCMessageView(ABCDispenseView[T_contra, F_contra], ABC, Generic[T_contra, F_contra]):
     handlers: List["ABCHandler"]
     state_source_key: str
-    default_text_approximators: List[Callable[["MessageMin"], str]]
+    default_text_approximators: List[Callable[["BaseMessageMin"], str]]
+    replace_mention = False
 
     def __init__(self):
         super().__init__()
@@ -30,12 +31,12 @@ class ABCMessageView(ABCDispenseView[T_contra, F_contra], ABC, Generic[T_contra,
 
     @staticmethod
     @abstractmethod
-    def get_event_type(event: T_contra):
+    def get_event_type(event: T_contra) -> Any:
         pass
 
     @staticmethod
     @abstractmethod
-    async def get_message(event: T_contra, ctx_api):
+    async def get_message(event: T_contra, ctx_api, replace_mention: bool) -> Any:
         pass
 
     async def handle_event(
@@ -45,7 +46,7 @@ class ABCMessageView(ABCDispenseView[T_contra, F_contra], ABC, Generic[T_contra,
         # https://dev.vk.com/api/user-long-poll/getting-started
         logger.debug("Handling event ({}) with message view".format(self.get_event_type(event)))
         context_variables: dict = {}
-        message = await self.get_message(event, ctx_api)
+        message = await self.get_message(event, ctx_api, self.replace_mention)
         message.state_peer = await state_dispenser.cast(self.get_state_key(message))
 
         for text_ax in self.default_text_approximators:
