@@ -5,12 +5,12 @@ AsyncFunc = Callable[..., Awaitable[Any]]
 
 
 class ABCErrorHandler(ABC):
-    error_handlers: Dict[Type[BaseException], AsyncFunc]
+    error_handlers: Dict[Type[Exception], AsyncFunc]
     undefined_error_handler: Optional[AsyncFunc]
 
     @abstractmethod
     def register_error_handler(
-        self, *error_types: Type[BaseException]
+        self, *error_types: Type[Exception]
     ) -> Callable[[AsyncFunc], AsyncFunc]:
         pass
 
@@ -19,7 +19,7 @@ class ABCErrorHandler(ABC):
         pass
 
     @abstractmethod
-    async def handle(self, error: BaseException) -> Any:
+    async def handle(self, error: Exception) -> Any:
         pass
 
     @abstractmethod
