@@ -20,8 +20,8 @@ def run_multibot(
     :param polling_type: polling type to be ran
     """
     for i, api_instance in enumerate(apis):
-        logger.debug(f"Connecting API (index: {i})")
+        logger.debug("Connecting API (index: {})", i)
         polling = polling_type().construct(api_instance)
         api_instance.http_client = SingleAiohttpClient()
         bot.loop_wrapper.add_task(bot.run_polling(custom_polling=polling))
-    bot.loop_wrapper.run_forever(bot.loop)
+    bot.loop_wrapper.run_forever()
