@@ -16,6 +16,7 @@ class ABCLabeler(ABC):
     raw_event_view: "ABCRawEventView"
     custom_rules: Dict[str, Type["ABCRule"]]
     auto_rules: List["ABCRule"]
+    raw_event_auto_rules: List["ABCRule"]
     rule_config: Dict[str, Any]
 
     @abstractmethod
@@ -34,7 +35,7 @@ class ABCLabeler(ABC):
     def raw_event(
         self,
         event: Union[str, List[str]],
-        dataclass: Callable,
+        dataclass: Any,
         *rules: "ABCRule",
         **custom_rules,
     ) -> "LabeledHandler":
