@@ -1,35 +1,37 @@
-import asyncio
-from typing import TYPE_CHECKING, Any, Optional
+from typing import TYPE_CHECKING, Any, Optional, Type, TypeVar
 
 from aiohttp import ClientSession, TCPConnector
 
 from vkbottle.modules import json as json_module
+from vkbottle.modules import logger
 
 from .abc import ABCHTTPClient
 
 if TYPE_CHECKING:
     from aiohttp import ClientResponse
 
+TSingleAiohttpClient = TypeVar("TSingleAiohttpClient", bound="SingleAiohttpClient")
+
 
 class AiohttpClient(ABCHTTPClient):
     def __init__(
         self,
-        loop: Optional[asyncio.AbstractEventLoop] = None,
         session: Optional[ClientSession] = None,
         json_processing_module: Optional[Any] = None,
         optimize: bool = False,
         **kwargs,
     ):
-        self.loop = loop or asyncio.get_event_loop()
         self.json_processing_module = json_processing_module or json_module
 
         if optimize:
             kwargs["skip_auto_headers"] = {"User-Agent"}
             kwargs["raise_for_status"] = True
+        if kwargs.pop("loop", None):
+            logger.warning("loop argument is deprecated")
 
         self.session = session
 
-        self.__session_params = kwargs
+        self._session_params = kwargs
 
     async def request_raw(
         self, url: str, method: str = "GET", data: Optional[dict] = None, **kwargs
@@ -38,7 +40,7 @@ class AiohttpClient(ABCHTTPClient):
             self.session = ClientSession(
                 connector=TCPConnector(ssl=False),
                 json_serialize=self.json_processing_module.dumps,
-                **self.__session_params,
+                **self._session_params,
             )
         async with self.session.request(url=url, method=method, data=data, **kwargs) as response:
             await response.read()
@@ -78,10 +80,12 @@ class AiohttpClient(ABCHTTPClient):
 class SingleAiohttpClient(AiohttpClient):
     __instance__ = None
 
-    def __new__(cls, *args, **kwargs):
-        if cls.__instance__ is not None:
-            return cls.__instance__
-        return super().__new__(cls, *args, **kwargs)
+    def __new__(
+        cls: Type[TSingleAiohttpClient], *args: Any, **kwargs: Any
+    ) -> TSingleAiohttpClient:
+        if cls.__instance__ is None:
+            cls.__instance__ = super().__new__(cls, *args, **kwargs)
+        return cls.__instance__
 
     def __aexit__(self, exc_type, exc_val, exc_tb):
         pass  # no need to close session in this case
