@@ -1,7 +1,7 @@
 import os
 import sys
 
-from watchgod import awatch
+from watchfiles import awatch
 
 from vkbottle.modules import logger
 
@@ -11,7 +11,7 @@ _startup_cwd = os.getcwd()
 def restart():
     """https://github.com/cherrypy/cherrypy/blob/0857fa81eb0ab647c7b59a019338bab057f7748b/cherrypy/process/wspbus.py#L305"""
     args = sys.argv[:]
-    logger.debug("Restarting: %s" % " ".join(args))
+    logger.debug("Restarting: {}", " ".join(args))
     args.insert(0, sys.executable)
     if sys.platform == "win32":
         args = ['"%s"' % arg for arg in args]
