@@ -1,13 +1,10 @@
-from typing import TYPE_CHECKING, Any, TypeVar
+from typing import Any
 
 try:
     import contextvars
 except ImportError:
     contextvars = None  # type: ignore
 
-if TYPE_CHECKING:
-    T = TypeVar("T")
-
 
 class BaseContext:
     """Parent BaseContext class. Idea taken from aiogram"""
@@ -28,5 +25,5 @@ class BaseContext:
         return cls.ctx_instance.get()
 
     @classmethod
-    def set_instance(cls, value: "T") -> None:
+    def set_instance(cls, value: Any) -> None:
         cls.ctx_instance.set(value)
