@@ -1,31 +1,41 @@
 from io import StringIO
-from typing import TYPE_CHECKING, Any, List, Optional, Union
+from typing import TYPE_CHECKING, List, Optional, Union
 
-from vkbottle_types.events.objects.group_event_objects import MessageEventObject
+from vkbottle_types.events import MessageEvent
 
-from vkbottle.dispatch.dispenser.base import StatePeer
+from vkbottle.modules import logger
 from vkbottle.tools.dev.event_data import OpenAppEvent, OpenLinkEvent, ShowSnackbarEvent
 
 if TYPE_CHECKING:
-    from vkbottle.api import ABCAPI, API
+    from vkbottle_types.responses.messages import MessagesSendUserIdsResponseItem
 
     EventDataType = Union[ShowSnackbarEvent, OpenAppEvent, OpenLinkEvent]
 
 
-class MessageEventMin(MessageEventObject):
-    unprepared_ctx_api: Optional[Any] = None
-    state_peer: Optional["StatePeer"] = None
-    group_id: Optional[int] = None
-
-    def __init__(self, **event):
-        data = event["object"]
-        data["group_id"] = event["group_id"]
-
-        super().__init__(**data)
+class MessageEventMin(MessageEvent):
+    @property
+    def user_id(self) -> int:
+        """alias to event.object.user_id"""
+        return self.object.user_id
 
     @property
-    def ctx_api(self) -> Union["ABCAPI", "API"]:
-        return getattr(self, "unprepared_ctx_api")
+    def peer_id(self) -> int:
+        """alias to event.object.peer_id"""
+        return self.object.peer_id
+
+    @property
+    def payload(self) -> Optional[dict]:
+        """alias to event.object.payload"""
+        return self.object.payload
+
+    @property
+    def conversation_message_id(self) -> int:
+        """alias to event.object.conversation_message_id"""
+        return self.object.conversation_message_id
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.event_id = self.object.event_id
 
     async def send_message_event_answer(self, event_data: "EventDataType", **kwargs) -> int:
         data = dict(
@@ -72,20 +82,13 @@ class MessageEventMin(MessageEventObject):
         self,
         message: Optional[str] = None,
         attachment: Optional[str] = None,
-        user_id: Optional[int] = None,
         random_id: Optional[int] = 0,
-        peer_id: Optional[int] = None,
-        peer_ids: Optional[List[int]] = None,
-        domain: Optional[str] = None,
-        chat_id: Optional[int] = None,
-        user_ids: Optional[List[int]] = None,
         lat: Optional[float] = None,
         long: Optional[float] = None,
         reply_to: Optional[int] = None,
         forward_messages: Optional[List[int]] = None,
         forward: Optional[str] = None,
         sticker_id: Optional[int] = None,
-        group_id: Optional[int] = None,
         keyboard: Optional[str] = None,
         template: Optional[str] = None,
         payload: Optional[str] = None,
@@ -95,23 +98,35 @@ class MessageEventMin(MessageEventObject):
         intent: Optional[str] = None,
         subscribe_id: Optional[int] = None,
         **kwargs,
-    ) -> int:
+    ) -> "MessagesSendUserIdsResponseItem":
         locals().update(kwargs)
 
         data = {k: v for k, v in locals().items() if k not in ("self", "kwargs") and v is not None}
-        required_params = ("peer_id", "user_id", "domain", "chat_id", "user_ids")
-        if not any(data.get(param) for param in required_params):
-            data["peer_id"] = self.peer_id
-
+        deprecated_params = ("peer_id", "user_id", "domain", "chat_id", "user_ids")
+        deprecated = [k for k in data if k in deprecated_params]
+        if deprecated:
+            logger.warning(
+                "Params like peer_id or user_id is deprecated in MessageEvent.send_message()."
+                "Use API.messages.send() instead"
+            )
+            for k in deprecated:
+                data.pop(k)
+        if message is None:
+            message = ""
+        elif not isinstance(message, str):
+            message = str(message)
         stream = StringIO(message)
         while True:
             msg = stream.read(4096)
             if msg:
                 data["message"] = msg
-            response = (await self.ctx_api.request("messages.send", data))["response"]
+            response = (await self.ctx_api.messages.send(peer_ids=[self.peer_id], **data))[0]  # type: ignore
             if stream.tell() == len(message or ""):
                 break
         return response
 
+    def get_payload_json(self, *args, **kwargs) -> Optional[dict]:
+        return self.payload
+
 
 MessageEventMin.update_forward_refs()
